@@ -52,6 +52,14 @@ templateObjectSchema = atapi.Schema((
         ),
     ),
 
+    atapi.LinesField(
+        name='setContentSubject',
+        required=0,
+        searchable=0,
+        default=(),
+    ),
+
+
     atapi.BooleanField(
         name='allowAnonymousAdd',
         required=0,
@@ -95,6 +103,14 @@ templateObjectSchema = atapi.Schema((
         schemata='hacks',
     ),
 
+    atapi.LinesField(
+        name='contentWorkflowTransitions',
+        required=0,
+        searchable=0,
+        default=('retract', 'hide'),
+        schemata='hacks',
+    ),
+
 ))
 
 
